@@ -215,6 +215,10 @@ class Polynomial2D:
             popt,pcov = curve_fit(self._n7,xx,yy)
         elif norder==8:
             popt,pcov = curve_fit(self._n8,xx,yy)
+        elif norder==9:
+            popt,pcov = curve_fit(self._n9,xx,yy)
+        elif norder==10:
+            popt,pcov = curve_fit(self._n10,xx,yy)
         else:
             popt,pcov = None,None
             print('Not support this norder')
@@ -310,6 +314,50 @@ class Polynomial2D:
         tmp += c35*np.power(x1,3)*np.power(x2,5) + c26*np.power(x1,2)*np.power(x2,6) + c17*x1*np.power(x2,7)
         tmp += c08*np.power(x2,8)
         return tmp
+    def _n9(self,x,c00,c10,c01,c20,c11,c02,
+            c30,c21,c12,c03,c40,c31,c22,c13,c04,
+            c50,c41,c32,c23,c14,c05,
+            c60,c51,c42,c33,c24,c15,c06,
+            c70,c61,c52,c43,c34,c25,c16,c07,
+            c80,c71,c62,c53,c44,c35,c26,c17,c08,
+            c90,c81,c72,c63,c54,c45,c36,c27,c18,c09
+           ):
+        x1,x2=x
+        tmp = self._n8(x,c00,c10,c01,c20,c11,c02,
+                       c30,c21,c12,c03,c40,c31,c22,c13,c04,
+                       c50,c41,c32,c23,c14,c05,
+                       c60,c51,c42,c33,c24,c15,c06,
+                       c70,c61,c52,c43,c34,c25,c16,c07,
+                       c80,c71,c62,c53,c44,c35,c26,c17,c08
+                      )
+        tmp += c90*np.power(x1,9) + c81*np.power(x1,8)*x2 + c72*np.power(x1,7)*np.power(x2,2)
+        tmp += c63*np.power(x1,6)*np.power(x2,3) + c54*np.power(x1,5)*np.power(x2,4) 
+        tmp += c45*np.power(x1,4)*np.power(x2,5) + c36*np.power(x1,3)*np.power(x2,6) + c27*np.power(x1,2)*np.power(x2,7)
+        tmp += c18*np.power(x1,1)*np.power(x2,8) + c09*np.power(x1,0)*np.power(x2,9)
+        return tmp
+    def _n10(self,x,c00,c10,c01,c20,c11,c02,
+            c30,c21,c12,c03,c40,c31,c22,c13,c04,
+            c50,c41,c32,c23,c14,c05,
+            c60,c51,c42,c33,c24,c15,c06,
+            c70,c61,c52,c43,c34,c25,c16,c07,
+            c80,c71,c62,c53,c44,c35,c26,c17,c08,
+            c90,c81,c72,c63,c54,c45,c36,c27,c18,c09,
+            ca0,c91,c82,c73,c64,c55,c46,c37,c28,c19,c0a
+           ):
+        x1,x2=x
+        tmp = self._n9(x,c00,c10,c01,c20,c11,c02,
+                       c30,c21,c12,c03,c40,c31,c22,c13,c04,
+                       c50,c41,c32,c23,c14,c05,
+                       c60,c51,c42,c33,c24,c15,c06,
+                       c70,c61,c52,c43,c34,c25,c16,c07,
+                       c80,c71,c62,c53,c44,c35,c26,c17,c08,
+                       c90,c81,c72,c63,c54,c45,c36,c27,c18,c09
+                      )
+        tmp += ca0*np.power(x1,10) + c91*np.power(x1,9)*x2 + c82*np.power(x1,8)*np.power(x2,2)
+        tmp += c73*np.power(x1,7)*np.power(x2,3) + c64*np.power(x1,6)*np.power(x2,4) 
+        tmp += c55*np.power(x1,5)*np.power(x2,5) + c46*np.power(x1,4)*np.power(x2,6) + c37*np.power(x1,3)*np.power(x2,7)
+        tmp += c28*np.power(x1,2)*np.power(x2,8) + c19*np.power(x1,1)*np.power(x2,9) + c0a*np.power(x1,0)*np.power(x2,10)
+        return tmp
     ##########
     ##########
     def _coefsize(self):
